==> elephant-archives-service-0.0.505-sources.jar: com/xforceplus/elephantarchives/controller/VolumeAppraisalRelationController.java <==
package com.xforceplus.elephantarchives.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.elephantarchives.entity.VolumeAppraisalRelation;
import com.xforceplus.elephantarchives.service.IVolumeAppraisalRelationService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * ${table.comment}前端控制器
 *
 * @author ultraman
 * @date 2021-08-27
 */
@RestController
public class VolumeAppraisalRelationController {

  @Autowired
  private IVolumeAppraisalRelationService volumeAppraisalRelationServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param volumeAppraisalRelation ${table.comment}
   * @return
   */
  @GetMapping("/volumeappraisalrelations" )
  public XfR getVolumeAppraisalRelations(XfPage page, VolumeAppraisalRelation volumeAppraisalRelation) {
    return XfR.ok(volumeAppraisalRelationServiceImpl.page(page, Wrappers.query(volumeAppraisalRelation)));
  }

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return XfR
   */
  @GetMapping("/volumeappraisalrelations/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(volumeAppraisalRelationServiceImpl.getById(id));
  }

  /**
   * 新增${table.comment}
   * @param volumeAppraisalRelation ${table.comment}
   * @return XfR
   */
  @PostMapping("/volumeappraisalrelations")
  public XfR save(@RequestBody VolumeAppraisalRelation volumeAppraisalRelation) {
     return XfR.ok(volumeAppraisalRelationServiceImpl.save(volumeAppraisalRelation));
  }

  /**
   * 修改-传入修改后的全部数据${table.comment}
   * @param volumeAppraisalRelation ${table.comment}
   * @return XfR
   */
  @PutMapping("/volumeappraisalrelations/{id}")
  public XfR putUpdate(@RequestBody VolumeAppraisalRelation volumeAppraisalRelation,@PathVariable Long id) {
      volumeAppraisalRelation.setId(id);
      return XfR.ok(volumeAppraisalRelationServiceImpl.updateById(volumeAppraisalRelation));
  }

  /**
   * 修改-传入修改的数据${table.comment}
   * @param volumeAppraisalRelation ${table.comment}
   * @return XfR
   */
  @PatchMapping("/volumeappraisalrelations/{id}")
  public XfR patchUpdate(@RequestBody VolumeAppraisalRelation volumeAppraisalRelation,@PathVariable Long id) {
      VolumeAppraisalRelation upvolumeAppraisalRelation = volumeAppraisalRelationServiceImpl.getById(id);
      if(upvolumeAppraisalRelation != null){
        upvolumeAppraisalRelation = ObjectCopyUtils.copyProperties(volumeAppraisalRelation,upvolumeAppraisalRelation,true);
      }
      return XfR.ok(volumeAppraisalRelationServiceImpl.updateById(upvolumeAppraisalRelation));
  }

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/volumeappraisalrelations/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(volumeAppraisalRelationServiceImpl.removeById(id));
  }

  @PostMapping("/volumeappraisalrelations/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "volume_appraisal_relation");
     params.put("request", condition);

     return XfR.ok(volumeAppraisalRelationServiceImpl.querys(params));
  }

}

==> elephant-archives-service-0.0.701-sources.jar: com/xforceplus/elephantarchives/controller/VolumeAppraisalRelationController.java <==
package com.xforceplus.elephantarchives.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.elephantarchives.entity.VolumeAppraisalRelation;
import com.xforceplus.elephantarchives.service.IVolumeAppraisalRelationService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * 档案鉴定申请关系前端控制器
 *
 * @author ultraman
 * @date 2021-11-08
 */
@RestController
public class VolumeAppraisalRelationController {

  @Autowired
  private IVolumeAppraisalRelationService volumeAppraisalRelationServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param volumeAppraisalRelation 档案鉴定申请关系
   * @return
   */
  @GetMapping("/volumeappraisalrelations" )
  public XfR getVolumeAppraisalRelations(XfPage page, VolumeAppraisalRelation volumeAppraisalRelation) {
    return XfR.ok(volumeAppraisalRelationServiceImpl.page(page, Wrappers.query(volumeAppraisalRelation)));
  }

  /**
   * 通过id查询档案鉴定申请关系
   * @param  id
   * @return XfR
   */
  @GetMapping("/volumeappraisalrelations/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(volumeAppraisalRelationServiceImpl.getById(id));
  }

  /**
   * 新增档案鉴定申请关系
   * @param volumeAppraisalRelation 档案鉴定申请关系
   * @return XfR
   */
  @PostMapping("/volumeappraisalrelations")
  public XfR save(@RequestBody VolumeAppraisalRelation volumeAppraisalRelation) {
     return XfR.ok(volumeAppraisalRelationServiceImpl.save(volumeAppraisalRelation));
  }

  /**
   * 修改-传入修改后的全部数据档案鉴定申请关系
   * @param volumeAppraisalRelation 档案鉴定申请关系
   * @return XfR
   */
  @PutMapping("/volumeappraisalrelations/{id}")
  public XfR putUpdate(@RequestBody VolumeAppraisalRelation volumeAppraisalRelation,@PathVariable Long id) {
      volumeAppraisalRelation.setId(id);
      return XfR.ok(volumeAppraisalRelationServiceImpl.updateById(volumeAppraisalRelation));
  }

  /**
   * 修改-传入修改的数据档案鉴定申请关系
   * @param volumeAppraisalRelation 档案鉴定申请关系
   * @return XfR
   */
  @PatchMapping("/volumeappraisalrelations/{id}")
  public XfR patchUpdate(@RequestBody VolumeAppraisalRelation volumeAppraisalRelation,@PathVariable Long id) {
      VolumeAppraisalRelation upvolumeAppraisalRelation = volumeAppraisalRelationServiceImpl.getById(id);
      if(upvolumeAppraisalRelation != null){
        upvolumeAppraisalRelation = ObjectCopyUtils.copyProperties(volumeAppraisalRelation,upvolumeAppraisalRelation,true);
      }
      return XfR.ok(volumeAppraisalRelationServiceImpl.updateById(upvolumeAppraisalRelation));
  }

  /**
   * 通过id删除档案鉴定申请关系
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/volumeappraisalrelations/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(volumeAppraisalRelationServiceImpl.removeById(id));
  }

  @PostMapping("/volumeappraisalrelations/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "volume_appraisal_relation");
     params.put("request", condition);

     return XfR.ok(volumeAppraisalRelationServiceImpl.querys(params));
  }

}
